@@ -26,13 +26,13 @@ class K3bOggVorbisDecoderFactory : public K3b::AudioDecoderFactory
 
 public:
     K3bOggVorbisDecoderFactory( QObject* parent, const QVariantList& );
-    ~K3bOggVorbisDecoderFactory();
+    ~K3bOggVorbisDecoderFactory() override;
 
-    bool canDecode( const QUrl& filename );
+    bool canDecode( const QUrl& filename ) override;
 
-    int pluginSystemVersion() const { return K3B_PLUGIN_SYSTEM_VERSION; }
+    int pluginSystemVersion() const override { return K3B_PLUGIN_SYSTEM_VERSION; }
 
-    K3b::AudioDecoder* createDecoder( QObject* parent = 0) const;
+    K3b::AudioDecoder* createDecoder( QObject* parent = 0) const override;
 };
 
 
@@ -45,18 +45,18 @@ class K3bOggVorbisDecoder : public K3b::AudioDecoder
 
 public: 
     explicit K3bOggVorbisDecoder( QObject* parent = 0 );
-    ~K3bOggVorbisDecoder();
+    ~K3bOggVorbisDecoder() override;
 
-    void cleanup();
+    void cleanup() override;
 
-    QString fileType() const;
+    QString fileType() const override;
 
 protected:
-    bool analyseFileInternal( K3b::Msf& frames, int& samplerate, int& ch );
-    bool initDecoderInternal();
-    bool seekInternal( const K3b::Msf& );
+    bool analyseFileInternal( K3b::Msf& frames, int& samplerate, int& ch ) override;
+    bool initDecoderInternal() override;
+    bool seekInternal( const K3b::Msf& ) override;
 
-    int decodeInternal( char* _data, int maxLen );
+    int decodeInternal( char* _data, int maxLen ) override;
 
 private:
     bool openOggVorbisFile();
